# Better Bing Image Downloader

### Disclaimer<br />

This program lets you download tons of images from Bing.
Please do not download or use any image that violates its copyright terms.

![GitHub top language](https://img.shields.io/github/languages/top/KTS-o7/better_bing_image_downloader)
![GitHub](https://img.shields.io/github/license/KTS-o7/better-bing-image-downloader)
[![Hits](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2FKTS-o7%2Fbetter_bing_image_downloader&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false)](https://hits.seeyoufarm.com)

### Installation <br />

```bash
git clone https://github.com/KTS-o7better_bing_image_downloader
cd better_bing_image_downloader
pip install .
```

or

```sh
pip install better-bing-image-downloader
```
